@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2012 - 2019 Andy Stewart <kb1oiq@arrl.net>
+   Copyright (C) 2012 - 2020 Andy Stewart <kb1oiq@arrl.net>
    Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -48,10 +48,10 @@ config_create (void)
 	preferences.longitude = 0.0;
 	preferences.EW = 1;
 	preferences.units = 1;
-	preferences.bands = g_strdup ("0.136,0.472,0.501,1.8,3.5,5,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+	preferences.bands = g_strdup ("0.136,0.472,0.501,1.8,3.5,5,7,10,14,18,21,24,28,40,50,54,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
 
 	preferences.modes = g_strndup
-	  ("AM,AMTORFEC,ARDOP,ASCI,ATV,C4FM,CHIP,CHIP64,CHIP128,CLO,CONTESTI,CW,DIGITALVOICE,DOMINO,DOMINOEX,DOMINOF,DSTAR,FAX,FM,FMHELL,FSK31,FSK441,FSKHELL,FSQCALL,FT4,FT8,GTOR,HELL,HELL80,HFSK,ISCAT,ISCAT_A,ISCAT_B,JS8,JT4,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65B2,JT65C,JT65C2,JT6M,JT9,JT9_1,JT9_2,JT9_5,JT9_10,JT9_30,JT9A,JT9B,JT9C,JT9D,JT9E,JT9E_FAST,JT9F,JT9F_FAST,JT9G,JT9G_FAST,JT9H,JT9H_FAST,LSB,MFSK,MFSK4,MFSK8,MFSK11,MFSK16,MFSK22,MFSK31,MFSK32,MFSK64,MFSK128,MSK144,MT63,OLIVIA,OLIVIA_4_125,OLIVIA_4_250,OLIVIA_8_250,OLIVIA_8_500,OLIVIA_16_500,OLIVIA_16_1000,OLIVIA_32_1000,OPERA,OPERA_BEACON,OPERA_QSO,PAC,PAC2,PAC3,PAC4,PAX,PAX2,PCW,PKT,PSK,PSK10,PSK31,PSK63,PSK63F,PSK125,PSK250,PSK500,PSK1000,PSK2K,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,QPSK250,QPSK500,QRA64,QRA64A,QRA64B,QRA64C,QRA64D,QRA64E,ROS,ROS_EME,ROS_HF,ROS_MF,RTTY,RTTYM,SIM31,SSB,SSTV,T10,THOR,THRB,THRBX,TOR,USB,V4,VOI,WINMOR,WSPR", 1024);
+	  ("AM,AMTORFEC,ARDOP,ASCI,ATV,C4FM,CHIP,CHIP64,CHIP128,CLO,CONTESTI,CW,DIGITALVOICE,DOMINO,DOMINOEX,DOMINOF,DSTAR,FAX,FM,FMHELL,FSK31,FSK441,FSKHELL,FSQCALL,FST4,FT4,FT8,GTOR,HELL,HELL80,HFSK,ISCAT,ISCAT_A,ISCAT_B,JS8,JT4,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65B2,JT65C,JT65C2,JT6M,JT9,JT9_1,JT9_2,JT9_5,JT9_10,JT9_30,JT9A,JT9B,JT9C,JT9D,JT9E,JT9E_FAST,JT9F,JT9F_FAST,JT9G,JT9G_FAST,JT9H,JT9H_FAST,LSB,MFSK,MFSK4,MFSK8,MFSK11,MFSK16,MFSK22,MFSK31,MFSK32,MFSK64,MFSK128,MSK144,MT63,OLIVIA,OLIVIA_4_125,OLIVIA_4_250,OLIVIA_8_250,OLIVIA_8_500,OLIVIA_16_500,OLIVIA_16_1000,OLIVIA_32_1000,OPERA,OPERA_BEACON,OPERA_QSO,PAC,PAC2,PAC3,PAC4,PAX,PAX2,PCW,PKT,PSK,PSK10,PSK31,PSK63,PSK63F,PSK125,PSK250,PSK500,PSK1000,PSK2K,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,QPSK250,QPSK500,QRA64,QRA64A,QRA64B,QRA64C,QRA64D,QRA64E,ROS,ROS_EME,ROS_HF,ROS_MF,RTTY,RTTYM,SIM31,SSB,SSTV,T10,THOR,THRB,THRBX,TOR,USB,V4,VOI,WINMOR,WSPR", 1024);
 	preferences.adif3_ok = 1;
 
 	preferences.bandseditbox = 0;
@@ -192,9 +192,9 @@ config_create (void)
 	preferences.scoringbands = g_new (gint, MAX_BANDS);
 	preferences.scoringbands[BAND_2190] = 0;
 	preferences.scoringbands[BAND_630] = 0;
-	preferences.scoringbands[BAND_560] = 1;
+	preferences.scoringbands[BAND_560] = 0;
 	preferences.scoringbands[BAND_160] = 1;
-	preferences.scoringbands[BAND_80] = 0;
+	preferences.scoringbands[BAND_80] = 1;
 	preferences.scoringbands[BAND_60] = 1;
 	preferences.scoringbands[BAND_40] = 1;
 	preferences.scoringbands[BAND_30] = 1;
@@ -202,10 +202,12 @@ config_create (void)
 	preferences.scoringbands[BAND_17] = 1;
 	preferences.scoringbands[BAND_15] = 1;
 	preferences.scoringbands[BAND_12] = 1;
-	preferences.scoringbands[BAND_10] = 0;
+	preferences.scoringbands[BAND_10] = 1;
+	preferences.scoringbands[BAND_8] = 0;
 	preferences.scoringbands[BAND_6] = 0;
+	preferences.scoringbands[BAND_5] = 0;
 	preferences.scoringbands[BAND_4] = 0;
-	preferences.scoringbands[BAND_2] = 0;
+	preferences.scoringbands[BAND_2] = 1;
 	preferences.scoringbands[BAND_125CM] = 0;
 	preferences.scoringbands[BAND_70CM] = 0;
 	preferences.scoringbands[BAND_33CM] = 0;
@@ -355,7 +357,9 @@ static void config_load_from_keyfile (GKeyFile *file)
 	  preferences.scoringbands[BAND_15] = 1;
 	  preferences.scoringbands[BAND_12] = 1;
 	  preferences.scoringbands[BAND_10] = 0;
+	  preferences.scoringbands[BAND_8] = 0;
 	  preferences.scoringbands[BAND_6] = 0;
+	  preferences.scoringbands[BAND_5] = 0;
 	  preferences.scoringbands[BAND_4] = 0;
 	  preferences.scoringbands[BAND_2] = 0;
 	  preferences.scoringbands[BAND_125CM] = 0;
@@ -379,13 +383,13 @@ static void config_load_from_keyfile (GKeyFile *file)
 
 	preferences.bands = g_key_file_get_string (file, "general", "bands", NULL);
 	if ((preferences.adif3_ok == 0) || (!preferences.bands)) {
-	  preferences.bands = g_strdup ("0.136,0.472,0.501,1.8,3.5,5,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+	  preferences.bands = g_strdup ("0.136,0.472,0.501,1.8,3.5,5,7,10,14,18,21,24,28,40,50,54,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
 	}
 
 	preferences.modes = g_key_file_get_string (file, "general", "modes", NULL);
 	if ((preferences.adif3_ok == 0) || (!preferences.modes)) {
 	  preferences.modes = g_strndup	
-	  ("AM,AMTORFEC,ARDOP,ASCI,ATV,C4FM,CHIP,CHIP64,CHIP128,CLO,CONTESTI,CW,DIGITALVOICE,DOMINO,DOMINOEX,DOMINOF,DSTAR,FAX,FM,FMHELL,FSK31,FSK441,FSKHELL,FSQCALL,FT4,FT8,GTOR,HELL,HELL80,HFSK,ISCAT,ISCAT_A,ISCAT_B,JS8,JT4,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65B2,JT65C,JT65C2,JT6M,JT9,JT9_1,JT9_2,JT9_5,JT9_10,JT9_30,JT9A,JT9B,JT9C,JT9D,JT9E,JT9E_FAST,JT9F,JT9F_FAST,JT9G,JT9G_FAST,JT9H,JT9H_FAST,LSB,MFSK,MFSK4,MFSK8,MFSK11,MFSK16,MFSK22,MFSK31,MFSK32,MFSK64,MFSK128,MSK144,MT63,OLIVIA,OLIVIA_4_125,OLIVIA_4_250,OLIVIA_8_250,OLIVIA_8_500,OLIVIA_16_500,OLIVIA_16_1000,OLIVIA_32_1000,OPERA,OPERA_BEACON,OPERA_QSO,PAC,PAC2,PAC3,PAC4,PAX,PAX2,PCW,PKT,PSK,PSK10,PSK31,PSK63,PSK63F,PSK125,PSK250,PSK500,PSK1000,PSK2K,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,QPSK250,QPSK500,QRA64,QRA64A,QRA64B,QRA64C,QRA64D,QRA64E,ROS,ROS_EME,ROS_HF,ROS_MF,RTTY,RTTYM,SIM31,SSB,SSTV,T10,THOR,THRB,THRBX,TOR,USB,V4,VOI,WINMOR,WSPR", 1024);
+	  ("AM,AMTORFEC,ARDOP,ASCI,ATV,C4FM,CHIP,CHIP64,CHIP128,CLO,CONTESTI,CW,DIGITALVOICE,DOMINO,DOMINOEX,DOMINOF,DSTAR,FAX,FM,FMHELL,FSK31,FSK441,FSKHELL,FSQCALL,FST4,FT4,FT8,GTOR,HELL,HELL80,HFSK,ISCAT,ISCAT_A,ISCAT_B,JS8,JT4,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65B2,JT65C,JT65C2,JT6M,JT9,JT9_1,JT9_2,JT9_5,JT9_10,JT9_30,JT9A,JT9B,JT9C,JT9D,JT9E,JT9E_FAST,JT9F,JT9F_FAST,JT9G,JT9G_FAST,JT9H,JT9H_FAST,LSB,MFSK,MFSK4,MFSK8,MFSK11,MFSK16,MFSK22,MFSK31,MFSK32,MFSK64,MFSK128,MSK144,MT63,OLIVIA,OLIVIA_4_125,OLIVIA_4_250,OLIVIA_8_250,OLIVIA_8_500,OLIVIA_16_500,OLIVIA_16_1000,OLIVIA_32_1000,OPERA,OPERA_BEACON,OPERA_QSO,PAC,PAC2,PAC3,PAC4,PAX,PAX2,PCW,PKT,PSK,PSK10,PSK31,PSK63,PSK63F,PSK125,PSK250,PSK500,PSK1000,PSK2K,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,QPSK250,QPSK500,QRA64,QRA64A,QRA64B,QRA64C,QRA64D,QRA64E,ROS,ROS_EME,ROS_HF,ROS_MF,RTTY,RTTYM,SIM31,SSB,SSTV,T10,THOR,THRB,THRBX,TOR,USB,V4,VOI,WINMOR,WSPR", 1024);
 	  preferences.adif3_ok = 1;
 	} else {
 	  preferences.adif3_ok = preferences.adif3_ok - 1;
