@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2012 - 2020 Andy Stewart <kb1oiq@arrl.net>
+   Copyright (C) 2012 - 2021 Andy Stewart <kb1oiq@arrl.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -399,7 +399,10 @@ gint adif_qso_append(LOGDB *handle, const qso_t *q)
 	int i, mode;
 	struct tm tm_a;
 	gchar *result;
-
+	gchar *distance;
+	gchar *distance_unit;
+        int distance_int;
+	
 	mode = adif3_mode2enum (q[MODE]);
 	if (mode == -1) {
 	  printf("ERROR: Illegal ADIF mode in adif_qso_append() with %s, mode %0d, callsign %s\n", q[MODE], mode, q[CALL]);
@@ -410,7 +413,7 @@ gint adif_qso_append(LOGDB *handle, const qso_t *q)
 	{
 		gint qfield_len, number;
 		gint fld = handle->column_fields[i];
-		gchar *qfield, *serial = NULL, *endptr = NULL, *space_ptr = NULL, *tmpfield;
+		gchar *qfield = NULL, *serial = NULL, *endptr = NULL, *space_ptr = NULL;
 
 		if (!q[fld])
 			continue;
@@ -503,20 +506,65 @@ gint adif_qso_append(LOGDB *handle, const qso_t *q)
 		  qfield_len = strlen(qfield);
 		}
 
-		else if (((fld == U1) && (!strcmp (xlog2adif_name(fld), "DISTANCE"))) ||
-				 ((fld == U2) && (!strcmp (xlog2adif_name(fld), "ANT_AZ"))))
-        {
-		  tmpfield = q[fld];
+		else if ((fld == U2) && (!strcmp (xlog2adif_name(fld), "ANT_AZ"))) {
+		  // Azimuth field is one of the following:
+		  //     null
+		  //     <number> deg
+		  //
+		  // The code looks for the space, and saves the part of the string prior to the space.
+                  // That value is the desired ADIF information for <ANT_AZ>
+		  // If there is no space, the field is null.
+		  
 		  space_ptr = q[fld];
 		  space_ptr = strpbrk (space_ptr, " ");
-		  qfield_len = space_ptr - tmpfield;
-
-		  if (qfield_len == 0) {
+		  qfield_len = space_ptr - q[fld];         // length of string from start to space
+		  
+		  if (qfield_len == 0) {                   // if no space, then the field is either null or somehow malformed
 			qfield = q[fld];
 		  } else {
-			strncpy (qfield, tmpfield, qfield_len);
-            #pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
-			qfield[qfield_len] = '\0';
+		    gchar tmp_str[10];
+		    strncpy (tmp_str, q[fld], qfield_len);  // Save the string from start to space, not including the space.
+		    qfield = tmp_str;
+		    qfield[qfield_len] = '\0';             // Null terminate the desired string
+		  }
+		}
+
+		else if ((fld == U1) && (!strcmp (xlog2adif_name(fld), "DISTANCE"))) {
+		  // Distance field is one of the following:
+		  //     null
+		  //     <number> m (must be converted to km)
+		  //     <number> km
+		  //
+		  // The code looks for the space, and saves the part of the string prior to the space.
+                  // That value is the desired ADIF information for <DISTANCE>
+		  // If there is no space, the field is null.
+		  
+		  space_ptr = q[fld];
+		  space_ptr = strpbrk (space_ptr, " ");
+		  qfield_len = space_ptr - q[fld];         // length of string from start to space
+
+		  if (qfield_len == 0) {                   // if no space, then the field is null
+			qfield = q[fld];
+		  } else {
+			// Convert distance to km
+			if (fld == U1)
+			{
+			  const char s[2] = " ";               // separate the numerical distance from the unit
+			  distance = strtok(q[fld], s);
+			  distance_unit = strtok(NULL, s);
+
+			  if (!strcmp(distance_unit, "m"))     // if the unit is miles, convert it to km per ADIF specification
+			  {
+			    distance_int = atoi(distance) * 1.6093;
+			  } else {
+			    distance_int = atoi(distance);
+			  }
+			  gchar tmp_str[10];
+			  sprintf(tmp_str, "%0d", distance_int);
+			  qfield_len = strlen(tmp_str);
+			  qfield = tmp_str;
+			  qfield[qfield_len] = '\0';
+			}
 		  }
 		}
 
